ScrollbarStyle class

Customizing scroll bar style. If not set thumbColor, other configuration will applied with the plaform system style scroll bar. If a specific Color is set for the thumb, all platform will use the RawScrollbar with the config set in this class.

Constructors

ScrollbarStyle({bool isAlwaysShown = false, double? thickness, Radius? radius, Color? thumbColor})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAlwaysShown → bool
Set whether always display thumb
final
radius → Radius?
Set raius of the thumb. If radius is null, the default value is platform dependent.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thickness → double?
Set the thickness of thumb. If thickness is null, the default value is platform dependent.
final
thumbColor → Color?
Set customized thumb color. If thumbColor is null, the default value is platform dependent.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited